#!env python
# -*- coding: iso-8859-1 -*-
###########################################################################
# 
# File:            sourceStEltronCanSerial.py
#
# License:         Donationware, see attached LICENSE file for more 
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.7e
#
# Date:            18.11.2015
#
# Description:     TaloLogger configuration wrapper for StEltronCanSerial library.
#                  
# Version history: ** 18.11.2015 v1.7e (Olli Lammi) **
#                  First version. 
#
###########################################################################

# Imports

from modules.core import configuration
from modules.core import dataSource

import stEltronCanSerial


###########################################################################

# Classes

class StEltronCanSerialConf(stEltronCanSerial.StiebelEltronCanSerial, configuration.Configurable, dataSource.DataSource):
    def __init__(self, modname):
        configuration.Configurable.__init__(self)
        self.setModuleName(modname)
        stEltronCanSerial.StiebelEltronCanSerial.__init__(self, None, None, None)
        dataSource.DataSource.__init__(self)
        self.setID(modname)

    def getServiceName(self):
        return self.getModuleName()

    def runDataSourceQueryCommandImpl(self, cmds):
        return self.runDataSourceQueryMultiWrapper(cmds)
    
    def handleConfiguration(self, conf):
        self.port = conf.getValue('SERIAL_PORT', '', self.getModuleName())
        self.device = conf.getValue('DEVICE', '', self.getModuleName())
        self.baudrate = conf.getValue('BAUDRATE', None, self.getModuleName())
        return (1, '')
        
    def initConfiguration(self):
        if len(self.port) <= 0:
            return (-1, 'Missing StEltronCan serial port path.')
        if len(self.device) <= 0:
            return (-1, 'Missing StEltronCan device name.')

        self.setPort(self.port)
        self.setDevice(self.device)
        self.setBaudrate(self.baudrate)

        if not self.startModule():
            return (0, 'Error accessing StEltronCan controller.')
        else:
            self.Log('Started StEltronCan serial module using device version: ' + self.getCanDeviceVersion())
        return (1, '')

    def releaseConfiguration(self):
        self.terminate()
        return (1, '')

    @staticmethod
    def getModuleTypeName():
        return 'STELTRONCAN'

    @staticmethod
    def getAllowedConfigurationKeys():
        return (['DEVICE', 'SERIAL_PORT', 'BAUDRATE'], [])

